@@ -1,12 +1,9 @@
 use serde::{Deserialize, Serialize};
 
-use super::defaults::{default_bool_true, default_disable_ctlseqs_alt};
+use super::defaults::{default_disable_ctlseqs_alt, default_ime_cursor_positioning};
 
 #[derive(Debug, Serialize, Deserialize, PartialEq, Clone, Copy)]
 pub struct Keyboard {
-    // Enable kitty keyboard protocol
-    #[serde(default = "default_bool_true", rename = "use-kitty-keyboard-protocol")]
-    pub use_kitty_keyboard_protocol: bool,
     // Disable ctlseqs with ALT keys
     // For example: Terminal.app does not deal with ctlseqs with ALT keys
     #[serde(
@@ -14,17 +11,25 @@ pub struct Keyboard {
         rename = "disable-ctlseqs-alt"
     )]
     pub disable_ctlseqs_alt: bool,
+
+    // Enable IME cursor positioning
+    // When enabled, the IME input popup will appear at the cursor position
+    #[serde(
+        default = "default_ime_cursor_positioning",
+        rename = "ime-cursor-positioning"
+    )]
+    pub ime_cursor_positioning: bool,
 }
 
 #[allow(clippy::derivable_impls)]
 impl Default for Keyboard {
     fn default() -> Keyboard {
         Keyboard {
-            use_kitty_keyboard_protocol: true,
             #[cfg(target_os = "macos")]
             disable_ctlseqs_alt: true,
             #[cfg(not(target_os = "macos"))]
             disable_ctlseqs_alt: false,
+            ime_cursor_positioning: default_ime_cursor_positioning(),
         }
     }
 }
