@@ -1,7 +1,7 @@
 use crate::components::core::shapes::Size;
 use crate::components::layer::atlas::{self, Atlas};
 use crate::components::layer::image::{Data, Handle};
-use image as image_rs;
+use tracing::debug;
 
 use rustc_hash::{FxHashMap, FxHashSet};
 
@@ -51,11 +51,11 @@ pub struct Cache {
 pub fn load_image(handle: &Handle) -> image_rs::ImageResult<image_rs::DynamicImage> {
     match handle.data() {
         Data::Path(path) => {
-            let image = ::image::open(path)?;
+            let image = image_rs::ImageReader::open(path)?.decode()?;
             Ok(image)
         }
         Data::Bytes(bytes) => {
-            let image = ::image::load_from_memory(bytes)?;
+            let image = image_rs::load_from_memory(bytes)?;
             Ok(image)
         }
         Data::Rgba {
@@ -88,6 +88,9 @@ impl Cache {
             return self.get(handle).unwrap();
         }
 
+        // Log cache miss for debugging
+        debug!("RasterCache miss for image handle_id={}", handle.id());
+
         let memory = match load_image(handle) {
             Ok(image) => Memory::Host(image.to_rgba8()),
             Err(image_rs::error::ImageError::IoError(_)) => Memory::NotFound,
@@ -105,13 +108,14 @@ impl Cache {
         encoder: &mut wgpu::CommandEncoder,
         handle: &crate::components::layer::image::Handle,
         atlas: &mut Atlas,
+        context: &crate::context::Context,
     ) -> Option<&atlas::Entry> {
         let memory = self.load(handle);
 
         if let Memory::Host(image) = memory {
             let (width, height) = image.dimensions();
 
-            let entry = atlas.upload(device, encoder, width, height, image)?;
+            let entry = atlas.upload(device, encoder, width, height, image, context)?;
 
             *memory = Memory::Device(entry);
         }
@@ -123,6 +127,12 @@ impl Cache {
         }
     }
 
+    /// Clear all cached images
+    pub fn clear(&mut self) {
+        self.map.clear();
+        self.hits.clear();
+    }
+
     /// Trim cache misses from cache
     pub fn trim(&mut self, atlas: &mut Atlas) {
         let hits = &self.hits;
